@@ -1,13 +1,13 @@
 import typer
 
 import os
-pwd = "/".join(__file__.split("/")[:-1])
+pwd = ".".join(__file__.split("/")[:-1])
 os.system("export PYTHONPATH="+pwd)
 
-import lib.wifi as wifi
-import lib.bt as bt
-import lib.util as util
-import lib.archive as archive
+import wifi as wifi
+import bt as bt
+import util as util
+import archive as archive
 
 
 main_app = typer.Typer()
